<?php

namespace Crm\Quote\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Crm\Quote\Actions\QuoteAction;
use Crm\Quote\Http\Requests\QuoteActionRequest;
use Crm\Quote\Http\Resources\QuoteResource;
use Crm\Quote\Models\Quote;

/**
 * Admin web controller class.
 */
class QuoteActionController extends BaseController
{

    /**
     * Action controller function for quote.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(QuoteActionRequest $request, Quote $quote, $action)
    {
        try {
            $request = $request->all();
            $quote = QuoteAction::run($action, $quote, $request);

            $data = new QuoteResource($quote);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('quote::quote.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('quote/quote/' . $quote->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('quote/quote/' . $quote->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
