<?php

namespace Crm\Quote\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Crm\Quote\Http\Resources\QuoteResource;
use Crm\Quote\Http\Resources\QuotesCollection;
use Crm\Quote\Scopes\QuotePublicScope;
use Crm\Quote\Models\Quote;

class QuotePublicController extends BaseController
{

    /**
     * Show quote's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Quote::pushScope(new RequestScope())
            ->pushScope(new QuotePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $quotes = new QuotesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('quote::quote.names'))
            ->view('quote::public.quote.index')
            ->data(compact('quotes', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show quote.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Quote::findBySlug($slug);
        $data = new QuoteResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('quote::quote.name'))
            ->view('quote::public.quote.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
