<?php

namespace Crm\Quote\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Quote\Events\QuoteAction as QuoteActionEvent;
use Crm\Quote\Notifications\QuoteAction as QuoteActionNotification;
use Litepie\Actions\Concerns\AsAction;

class QuoteAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the QuoteActionEvent.
     *
     * @param   QuoteActionEvent  $event
     * @return mixed
     */
    public function handle(QuoteActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $quote.
     *
     * @param   QuoteActionEvent  $event
     * @return void
     */
    public function create(QuoteActionEvent $event)
    {
        $client = $event->quote->client;
        Notification::send($client, new QuoteActionNotification($event));
    }

    /**
     * Handle the QuoteActionEvent as a listener.
     *
     * @param   QuoteActionEvent  $event
     * @return mixed
     */
    public function asListener(QuoteActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   QuoteActionEvent  $event
     * @return bool
     */
    private function isAllowed(QuoteActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
