<?php

namespace Crm\Quote\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Quote\Events\QuoteWorkflow as QuoteWorkflowEvent;
use Crm\Quote\Notifications\QuoteWorkflow as QuoteWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class QuoteWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(QuoteWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $quote is submitted.
     *
     * @param QuoteWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(QuoteWorkflowEvent $event)
    {
        $client = $event->quote->client;
        Notification::send($client, new QuoteWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $quote is published.
     *
     * @param QuoteWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(QuoteWorkflowEvent $event)
    {
        $client = $event->quote->client;
        Notification::send($client, new QuoteWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $quote is approved.
     *
     * @param QuoteWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(QuoteWorkflowEvent $event)
    {
        $client = $event->quote->client;
        Notification::send($client, new QuoteWorkflowNotification($event));
    }

    /**
     * Handles the $quote workflow event as a listener.
     *
     * @param QuoteWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(QuoteWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
