<?php
namespace Crm\Quote\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Crm\Quote\Events\QuoteAction as QuoteActionEvent;
use Crm\Quote\Models\Quote;

class QuoteAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $quote;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param QuoteActionEvent $quote
     */
    public function __construct(QuoteActionEvent $quote)
    {
        $this->action = $event->action;
        $this->quote = $quote;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Quote Approved - ' . config('app.name'))
            ->view('quote::quote.email.action', ['data' => $this->quote]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
