<?php

namespace Crm\Quote\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Quote\Models\Quote;

class QuotePolicy
{

    use QuoteAction;

    /**
     * Determine if the given user can view the quote.
     *
     * @param Authenticatable $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function view(Authenticatable $user, Quote $quote)
    {
        if ($authUser->canDo('quote.quote.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $quote->is_owner;
    }

    /**
     * Determine if the given user can create a quote.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('quote.quote.create');
    }

    /**
     * Determine if the given user can update the given quote.
     *
     * @param Authenticatable $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function update(Authenticatable $user, Quote $quote)
    {
        if ($user->canDo('quote.quote.edit') && $user->isAdmin()) {
            return true;
        }

        return $quote->is_owner;
    }

    /**
     * Determine if the given user can delete the given quote.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Quote $quote)
    {
        return $quote->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
